@@ -12,6 +12,7 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import re
 
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
@@ -23,7 +24,7 @@ import yaml
 import time
 import os
 import logging as log
-from qubell.api.private.platform import Auth
+
 
 def rand():
     return str(randrange(1000, 9999))
@@ -31,32 +32,54 @@ def rand():
 def cpath(file):
     return os.path.join(os.path.dirname(__file__), file)
 
-def retry(tries=5, delay=3, backoff=2):
+def retry(tries=5, delay=3, backoff=2, retry_exception=None):
     """
-    Retry "tries" times, with initial "delay", increasing delay "delay*backoff" each time
+    Retry "tries" times, with initial "delay", increasing delay "delay*backoff" each time.
+    Without exception success means when function returns valid object.
+    With exception success when no exceptions
     """
 
     def deco_retry(f):
         def f_retry(*args, **kwargs):
             mtries, mdelay = tries, delay
-            rv = f(*args, **kwargs)
+
             while mtries > 0:
-                if rv is True:
+                try:
+                    rv = f(*args, **kwargs)
+                except retry_exception:
+                    rv = False
+                else:
+                    #if we expect to catch something, but f, doesn't return anything
+                    #another word, nice indicator if no exceptions
+                    if retry_exception:
+                        rv = True
+                if rv:
                     return True
                 mtries -= 1
+                log.debug("...{0} sleeping for {1} s in retry".format(f.__name__,mdelay))
                 time.sleep(mdelay)
                 mdelay *= backoff
-                rv = f(*args, **kwargs)
-            return False
+            return f(*args, **kwargs)
         return f_retry
     return deco_retry
 
-def waitForStatus(instance, final='Running', accepted=['Requested'], timeout=[20, 10, 1]):
+def waitForStatus(instance, final='Running', accepted=None, timeout=(20, 10, 1)):
+    if not accepted: accepted = ['Requested']
+
     log.debug('Waiting status: %s' % final)
-    import time #TODO: We have to wait, because privious status takes time to change to new one
-    time.sleep(10)
+    import time
+
+    @retry(3, 1, 2) # max = 1 + 2 + 4 = 7 seconds + routes time
+    def projection_update_monitor():
+        """
+        We have to deal with lag when projection updates instance.
+        :return:
+        """
+        return instance.status != final and instance._is_projection_updated_instance()
+    projection_update_monitor()
+
     @retry(*timeout) # ask status 20 times every 10 sec.
-    def waiter():
+    def instance_status_waiter():
         cur_status = instance.status
         if cur_status in final:
             log.info('Got status: %s, continue' % cur_status)
@@ -66,17 +89,19 @@ def waitForStatus(instance, final='Running', accepted=['Requested'], timeout=[20
             return False
         else:
             log.error('Got unexpected instance status: %s' % cur_status)
-            return True # Let retry exit
+            return True  # Let retry exit
 
-    waiter()
+    instance_status_waiter()
     # We here, means we reached timeout or got status we are waiting for.
     # Check it again to be sure
 
     cur_status = instance.status
     log.info('Final status: %s' % cur_status)
+    instance._last_workflow_started_time = time.gmtime(time.time())
     if cur_status in final:
         return True
     else:
+        log.error("Didn't get '{0}' stopped in '{1}' with error '''{2}'''".format(final, cur_status, instance.error))
         return False
 
 def dump(node):
@@ -90,7 +115,6 @@ def dump(node):
     from qubell.api.private.revision import Revision
     from qubell.api.private.provider import Provider
     from qubell.api.private.environment import Environment
-    from qubell.api.private.service import Service
     from qubell.api.private.zone import Zone
     from qubell.api.private.manifest import Manifest
 
@@ -106,7 +130,6 @@ def dump(node):
         Revision: ['auth', 'revisionId'],
         Provider: ['auth', 'providerId', 'organization'],
         Environment: ['auth', 'environmentId', 'organization'],
-        Service: ['auth', 'organization', 'zone', 'serviceId'],
         Zone: ['auth', 'zoneId', 'organization'],
     }
 
@@ -118,7 +141,7 @@ def dump(node):
                     try:
                         fields.pop(excl_item)
                     except:
-                        print 'No item %s in object %s' % (excl_item, x)
+                        log.warn('No item %s in object %s' % (excl_item, x))
                 return dumper.represent_mapping('tag:yaml.org,2002:map', fields)
         return dumper.represent_mapping('tag:yaml.org,2002:map', obj.__dict__)
 
@@ -135,3 +158,29 @@ def full_dump(org):
     """ TODO:  Dump all that reports by api
     """
     pass
+
+def lazyproperty(fn):
+    """
+    Decorator, reads property once, on first use.
+    :param fn:
+    :return:
+    """
+    attr_name = '_lazy_' + fn.__name__
+    @property
+    def _lazyprop(self):
+        if attr_name not in self.__dict__:  # don't use hasattr, due to call of __getattr__
+            setattr(self, attr_name, fn(self))
+        return getattr(self, attr_name)
+    return _lazyprop
+
+
+def lazy(func):
+    def lazyfunc(*args, **kwargs):
+        wrapped = lambda x : func(*args, **kwargs)
+        wrapped.__name__ = "lazy-" + func.__name__
+        return wrapped
+    return lazyfunc
+
+def is_bson_id(bson_id):
+    id_pattern = u'[A-Fa-f0-9]{24}'
+    return re.match(id_pattern, unicode(bson_id))
\ No newline at end of file
